@@ -3,7 +3,7 @@ from text_alignment_tool.alignment_algorithms import (
     AlignmentException,
     GlobalAlignmentAlgorithm,
     LocalAlignmentAlgorithm,
-    RoughAlignmentAlgorithm,
+    NeedleInHaystackAlgorithm,
     ChunkAlignmentAlgorithm,
 )
 
