@@ -11,8 +11,8 @@ from text_alignment_tool.alignment_algorithms.local_alignment import (
     LocalAlignmentAlgorithm,
     local_alignment,
 )
-from text_alignment_tool.alignment_algorithms.rough_alignment import (
-    RoughAlignmentAlgorithm,
+from text_alignment_tool.alignment_algorithms.needle_in_haystack_alignment import (
+    NeedleInHaystackAlgorithm,
 )
 from text_alignment_tool.alignment_algorithms.chunk_alignment import (
     ChunkAlignmentAlgorithm,
