@@ -1,5 +1,6 @@
 # TODO: update for real support of new TextChunk data structure
 
+from typing import List, Dict, Tuple
 import edlib
 from text_alignment_tool.alignment_algorithms import AlignmentAlgorithm
 from text_alignment_tool.shared_classes import (
@@ -36,14 +37,14 @@ class ChunkAlignmentAlgorithm(AlignmentAlgorithm):
 
         # Find best matches for lines
         alignment = TextAlignments()
-        linewise_dict: dict[int, list[int]] = {}
+        linewise_dict: Dict[int, List[int]] = {}
         for linewise_match in linewise_matches:
             if linewise_match[0] not in linewise_dict:
                 linewise_dict[linewise_match[0]] = []
             linewise_dict[linewise_match[0]].append(linewise_match[1])
 
         # Calculate the actual corresponding chunks of the lines
-        query_target_text_chunk_alignment: list[tuple[TextChunk, TextChunk]] = []
+        query_target_text_chunk_alignment: List[Tuple[TextChunk, TextChunk]] = []
         for linewise_match_key in linewise_dict.keys():
             query_text_chunk_indices = self._input_query_text_chunk_indices[
                 linewise_match_key
@@ -135,9 +136,9 @@ class ChunkAlignmentAlgorithm(AlignmentAlgorithm):
 def comprehensive_linewise_matching(
     query_text: LetterList,
     target_text: LetterList,
-    query_text_chunk_bounds: list[TextChunk],
-    target_text_chunk_bounds: list[TextChunk],
-) -> list[tuple[int, int]]:
+    query_text_chunk_bounds: List[TextChunk],
+    target_text_chunk_bounds: List[TextChunk],
+) -> List[Tuple[int, int]]:
     query_text_chunks = [
         "".join(chr(y) for y in query_text[x.indices]) for x in query_text_chunk_bounds
     ]
@@ -148,7 +149,7 @@ def comprehensive_linewise_matching(
     ]
     mean_target_length = mean([len(x) for x in target_text_chunks])
 
-    scored_matches: list[tuple[int, int, int]] = []
+    scored_matches: List[Tuple[int, int, int]] = []
     for target_index, target_text_chunk in enumerate(target_text_chunks):
         for query_index, query_text_chunk in enumerate(query_text_chunks):
             ratio = (
@@ -160,9 +161,9 @@ def comprehensive_linewise_matching(
             pair_distance = ratio(query_text_chunk, target_text_chunk)
             scored_matches.append((pair_distance, query_index, target_index))
 
-    best_matches: list[tuple[int, int, int]] = []
+    best_matches: List[Tuple[int, int, int]] = []
     sorted_scored_matches = sorted(scored_matches, key=lambda x: x[0], reverse=True)
-    remaining_matches: list[tuple[int, int, int]] = sorted_scored_matches.copy()
+    remaining_matches: List[Tuple[int, int, int]] = sorted_scored_matches.copy()
     for match in sorted_scored_matches:
         if match not in remaining_matches:
             continue
@@ -183,8 +184,8 @@ def perform_global_alignment(
     target_text: LetterList,
     query_offset: int,
     target_offset: int,
-) -> list[AlignmentKey]:
-    alignments: list[AlignmentKey] = []
+) -> List[AlignmentKey]:
+    alignments: List[AlignmentKey] = []
     query = "".join([chr(x) for x in query_text])
     target = "".join([chr(x) for x in target_text])
 
@@ -205,7 +206,7 @@ def perform_global_alignment(
 def perform_local_chunk_alignment(
     query_text: LetterList,
     target_text: LetterList,
-) -> tuple[int, int, int, int]:
+) -> Tuple[int, int, int, int]:
     # choose your own values here… 2 and -1 are common.
     match = 2
     mismatch = -1
