@@ -4,7 +4,7 @@ from text_alignment_tool.alignment_algorithms import (
     AlignmentException,
     AlignmentAlgorithm,
 )
-from typing import Union
+from typing import Union, List, Dict
 from text_alignment_tool.alignment_tool.aligner import (
     AlignmentOperation,
     QueryTargetAlignment,
@@ -19,12 +19,6 @@ from text_alignment_tool.text_loaders import TextLoader
 from text_alignment_tool.text_transformers import TextTransformer
 
 
-def debugger_is_active() -> bool:
-    """Return if the debugger is currently active"""
-    gettrace = getattr(sys, "gettrace", lambda: None)
-    return gettrace() is not None
-
-
 class TextAlignmentTool:
     """
     The text alignment tool provides a context within which
@@ -35,15 +29,9 @@ class TextAlignmentTool:
     """
 
     def __init__(self, query_loader: TextLoader, target_loader: TextLoader):
-        if debugger_is_active():
-            # In debugging mode, inject some root level utilities
-            # to make it easire to visualize the text and chunks
-            main_mod = sys.modules["__main__"]
-            main_mod.__builtins__["dbg"] = DebugHelper()
-
         self.__query_loader: TextLoader = query_loader
         self.__target_loader: TextLoader = target_loader
-        self.__operation_list: list[AlignmentOperation] = []
+        self.__operation_list: List[AlignmentOperation] = []
         self.__load_texts()
 
     def __load_texts(self):
@@ -67,7 +55,7 @@ class TextAlignmentTool:
             AlignmentOperation(None, no_operation_target_transform, None)
         )
 
-    def query_text_transforms(self, query_transformers: list[TextTransformer]):
+    def query_text_transforms(self, query_transformers: List[TextTransformer]):
         """
         Apply any number of transformations to the query text
         in the order submitted.
@@ -88,7 +76,7 @@ class TextAlignmentTool:
 
         self.query_text_transforms([query_transformers])
 
-    def target_text_transforms(self, target_transformers: list[TextTransformer]):
+    def target_text_transforms(self, target_transformers: List[TextTransformer]):
         """
         Apply any number of transformations to the target text
         in the order submitted.
@@ -109,7 +97,7 @@ class TextAlignmentTool:
 
         self.target_text_transforms([target_transformer])
 
-    def align_texts(self, alignment_algorithms: list[AlignmentAlgorithm]):
+    def align_texts(self, alignment_algorithms: List[AlignmentAlgorithm]):
         """
         Apply any number of alignment operations to the query and target
         texts in the order specified.
@@ -139,26 +127,26 @@ class TextAlignmentTool:
 
         self.align_texts([alignment_algorithm])
 
-    def collect_all_alignments(self) -> list[list[QueryTargetAlignment]]:
+    def collect_all_alignments(self) -> List[List[QueryTargetAlignment]]:
         """Based on the latest alignment, calculate all possible correspondances
         between every stage of the query and the target transformation
         pipeline.
 
         Returns:
-            list[list[QueryTargetAlignment]]: this 2D list contains every possible
+            List[List[QueryTargetAlignment]]: this 2D list contains every possible
             alignment of the query and target. The 1st axis tracks the query text
             from latest to earliest. The 2nd axis tracks the target text from
             latest to earliest.
         """
-        results: list[list[QueryTargetAlignment]] = []
+        results: List[List[QueryTargetAlignment]] = []
 
         # Collect all possible query and target transforms
-        query_transforms: list[AlignmentOperation] = [
+        query_transforms: List[AlignmentOperation] = [
             x
             for x in self.__operation_list
             if x.query_transformation is not None  # or x.alignment is not None
         ]
-        target_transforms: list[AlignmentOperation] = [
+        target_transforms: List[AlignmentOperation] = [
             x
             for x in self.__operation_list
             if x.target_transformation is not None  # or x.alignment is not None
@@ -173,14 +161,14 @@ class TextAlignmentTool:
                 and query_alignment_operation.query_transformation is not None
             ):
                 stored_alignment: Union[TextAlignments, None] = None
-                current_query_target_alignment: list[QueryTargetAlignment] = []
+                current_query_target_alignment: List[QueryTargetAlignment] = []
                 current_query_text = (
                     query_alignment_operation.query_transformation.input
                 )
                 current_query_text_chunks = (
                     query_alignment_operation.query_transformation.input_text_chunk_indices
                 )
-                aligned_query_to_current_query: dict[int, list[int]] = {}
+                aligned_query_to_current_query: Dict[int, List[int]] = {}
                 for (
                     input_output_map_entry
                 ) in query_alignment_operation.query_transformation.input_output_map:
@@ -209,7 +197,7 @@ class TextAlignmentTool:
                         current_target_text_chunks = (
                             target_alignment_operation.target_transformation.input_text_chunk_indices
                         )
-                        aligned_target_to_current_target: dict[int, list[int]] = {}
+                        aligned_target_to_current_target: Dict[int, List[int]] = {}
                         for (
                             input_output_map_entry
                         ) in (
@@ -270,80 +258,6 @@ class TextAlignmentTool:
         results.insert(0, [final_alignment])
         return results
 
-    # def find_alignment_to_query(self) -> list[QueryTargetAlignment]:
-    #     """
-    #     Walk the latest alignment mapping back to the earliest
-    #     form of the target text.
-    #     """
-
-    #     query_transforms: list[AlignmentOperation] = [
-    #         x
-    #         for x in self.__operation_list
-    #         if x.query_transformation is not None or x.alignment is not None
-    #     ]
-    #     latest_target_text = self.__latest_target_text
-    #     latest_alignment: Union[TextAlignments, None] = None
-    #     alignment_history: list[QueryTargetAlignment] = []
-    #     for alignment_operation in reversed(query_transforms):
-    #         if alignment_operation.alignment is not None:
-    #             latest_alignment = alignment_operation.alignment._alignment
-    #         if (
-    #             latest_alignment is not None
-    #             and alignment_operation.query_transformation is not None
-    #         ):
-    #             latest_alignment = (
-    #                 alignment_operation.query_transformation.apply_alignment(
-    #                     latest_alignment
-    #                 )
-    #             )
-    #             alignment_history.append(
-    #                 QueryTargetAlignment(
-    #                     latest_alignment,
-    #                     alignment_operation.query_transformation.input,
-    #                     alignment_operation.query_transformation.input_text_chunk_indices,
-    #                     latest_target_text,
-    #                 )
-    #             )
-
-    #     return alignment_history
-
-    # def find_alignment_to_target(self) -> list[QueryTargetAlignment]:
-    #     """
-    #     Walk the latest alignment mapping back to the earliest
-    #     form of the query text.
-    #     """
-
-    #     target_transforms: list[AlignmentOperation] = [
-    #         x
-    #         for x in self.__operation_list
-    #         if x.target_transformation is not None or x.alignment is not None
-    #     ]
-    #     latest_query_text = self.__latest_query_text
-    #     latest_alignment: Union[TextAlignments, None] = None
-    #     alignment_history: list[QueryTargetAlignment] = []
-    #     for alignment_operation in reversed(target_transforms):
-    #         if alignment_operation.alignment is not None:
-    #             latest_alignment = alignment_operation.alignment._alignment
-    #         if (
-    #             latest_alignment is not None
-    #             and alignment_operation.target_transformation is not None
-    #         ):
-    #             latest_alignment = (
-    #                 alignment_operation.target_transformation.apply_alignment(
-    #                     latest_alignment
-    #                 )
-    #             )
-    #             alignment_history.append(
-    #                 QueryTargetAlignment(
-    #                     latest_alignment,
-    #                     alignment_operation.target_transformation.input,
-    #                     alignment_operation.target_transformation.input_text_chunk_indices,
-    #                     latest_query_text,
-    #                 )
-    #             )
-
-    #     return alignment_history
-
     @property
     def latest_alignment(self) -> AlignmentAlgorithm:
         alignments = [
@@ -360,14 +274,14 @@ class TextAlignmentTool:
         return self.__operation_list[-1]
 
     @property
-    def __latest_query_operation_text_chunks(self) -> list[TextChunk]:
+    def __latest_query_operation_text_chunks(self) -> List[TextChunk]:
         transformer = [
             x for x in self.__operation_list if x.query_transformation is not None
         ][-1].query_transformation
         return transformer.text_chunk_indices if transformer is not None else []
 
     @property
-    def __latest_target_operation_text_chunks(self) -> list[TextChunk]:
+    def __latest_target_operation_text_chunks(self) -> List[TextChunk]:
         transformer = [
             x for x in self.__operation_list if x.target_transformation is not None
         ][-1].target_transformation
@@ -378,7 +292,7 @@ class TextAlignmentTool:
         return self.__latest_query_transform.output
 
     @property
-    def __latest_query_text_chunk_indices(self) -> list[TextChunk]:
+    def __latest_query_text_chunk_indices(self) -> List[TextChunk]:
         return (
             self.__latest_operation.alignment.output_query_text_chunk_indices
             if self.__latest_operation.alignment is not None
@@ -390,7 +304,7 @@ class TextAlignmentTool:
         return self.__query_text_operations[-1]
 
     @property
-    def __query_text_operations(self) -> list[TextTransformer]:
+    def __query_text_operations(self) -> List[TextTransformer]:
         return [
             x.query_transformation
             for x in self.__operation_list
@@ -402,7 +316,7 @@ class TextAlignmentTool:
         return self.__latest_target_transform.output
 
     @property
-    def __latest_target_text_chunk_indices(self) -> list[TextChunk]:
+    def __latest_target_text_chunk_indices(self) -> List[TextChunk]:
         return (
             self.__latest_operation.alignment.output_target_text_chunk_indices
             if self.__latest_operation.alignment is not None
@@ -414,7 +328,7 @@ class TextAlignmentTool:
         return self.__target_text_operations[-1]
 
     @property
-    def __target_text_operations(self) -> list[TextTransformer]:
+    def __target_text_operations(self) -> List[TextTransformer]:
         return [
             x.target_transformation
             for x in self.__operation_list
@@ -457,8 +371,8 @@ class DebugHelper:
 
     @classmethod
     def display_text_chunks(
-        cls, text: LetterList, chunks: list[TextChunk]
-    ) -> list[str]:
+        cls, text: LetterList, chunks: List[TextChunk]
+    ) -> List[str]:
         """
         Print out a human readable representation of the letter list
         for the specified text chunks.
