@@ -1,14 +1,17 @@
+from typing import List
+from typing import TypeVar
 from dataclasses import dataclass
 import numpy as np
+import numpy.typing as npt
 
 
-LetterList = np.ndarray
+LetterList = npt.NDArray[np.uint32]
 
 
 @dataclass(init=True, frozen=True)
 class TextChunk:
     __slots__ = ("indices", "name")
-    indices: list[int]
+    indices: List[int]
     name: str
 
 
@@ -20,4 +23,4 @@ class AlignmentKey:
 
 class TextAlignments:
     def __init__(self):
-        self.alignments: list[AlignmentKey] = []
\ No newline at end of file
+        self.alignments: List[AlignmentKey] = []
