@@ -2,7 +2,7 @@ import pandas as pd
 from lxml import etree
 from dotmap import DotMap
 from pathlib import Path
-from typing import NamedTuple
+from typing import NamedTuple, List, Dict
 from text_alignment_tool.shared_classes import TextChunk, LetterList, TextAlignments
 from text_alignment_tool.text_loaders.text_loader import TextLoader
 import numpy as np
@@ -19,17 +19,15 @@ class AltoAlignmentMap(NamedTuple):
 
 
 class AltoXMLTextLoader(TextLoader):
-    def __init__(
-        self, file_path: Path, estimated_number_of_lines_per_page: int = 60
-    ):
+    def __init__(self, file_path: Path, estimated_number_of_lines_per_page: int = 60):
         self.__serialized_xml = pd.DataFrame()
         self.__estimated_number_of_lines_per_page = estimated_number_of_lines_per_page
         super().__init__(file_path)
-        self._input_output_map: list[AltoAlignmentMap] = []
+        self._input_output_map: List[AltoAlignmentMap] = []
 
     def _load(self) -> LetterList:
         self.import_ocr_texts()
-        tokens: list[int] = []
+        tokens: List[int] = []
         token_idx_count = 0
         for _, row in self.__serialized_xml.iterrows():
             chunk_start_idx = token_idx_count
@@ -44,7 +42,10 @@ class AltoXMLTextLoader(TextLoader):
             chunk_end_idx = token_idx_count
             if chunk_start_idx < chunk_end_idx:
                 self._text_chunk_indices.append(
-                    TextChunk(list(range(chunk_start_idx, chunk_end_idx + 1)), str(row.line_ID))
+                    TextChunk(
+                        list(range(chunk_start_idx, chunk_end_idx + 1)),
+                        str(row.line_ID),
+                    )
                 )
         self._output: LetterList = np.array(tokens)
 
@@ -287,14 +288,14 @@ class AltoXMLTextLoader(TextLoader):
         self, alignment_pairs: TextAlignments, aligned_text: LetterList
     ) -> pd.DataFrame:
         # TODO: the emandation is not working quite right.
-        alignment_pairs_dict: dict[int, list[int]] = {}
+        alignment_pairs_dict: Dict[int, List[int]] = {}
         for alignment in alignment_pairs.alignments:
             if alignment.query_idx not in alignment_pairs_dict:
                 alignment_pairs_dict[alignment.query_idx] = []
 
             alignment_pairs_dict[alignment.query_idx].append(alignment.target_idx)
 
-        input_to_aligned_text_map: list[AltoAlignmentMap] = []
+        input_to_aligned_text_map: List[AltoAlignmentMap] = []
         for input_position, output_idx in [
             (x.input_position, x.output_idx) for x in self._input_output_map
         ]:
@@ -305,7 +306,7 @@ class AltoXMLTextLoader(TextLoader):
                     )
                     pass
 
-        input_to_aligned_text_map_dict: dict[str, list[int]] = {}
+        input_to_aligned_text_map_dict: Dict[str, List[int]] = {}
         # Yeah, that's a hacky bunch of shit in the middle to make the input key unique (it's almost the weekend and I don't want to think about the "right" way to do it)
         garbage = "@#$%^&"
         for alignment in input_to_aligned_text_map:
@@ -317,8 +318,8 @@ class AltoXMLTextLoader(TextLoader):
                 alignment.output_idx
             )
 
-        # aligned_transcription: list[str] = []
-        used_alinment_text_indices: list[int] = []
+        # aligned_transcription: List[str] = []
+        used_alinment_text_indices: List[int] = []
         for idx, entry in self.__serialized_xml.iterrows():
             line_text = ""
             for char_idx in range(len(entry.txt)):
@@ -340,14 +341,14 @@ class AltoXMLTextLoader(TextLoader):
     ) -> pd.DataFrame:
         # TODO: as written this was originally going to be used to correct individual letters in the original
         # I repurposed it to simply replace the text with its match, but that can probably be done more simply.
-        alignment_pairs_dict: dict[int, list[int]] = {}
+        alignment_pairs_dict: Dict[int, List[int]] = {}
         for alignment in alignment_pairs.alignments:
             if alignment.query_idx not in alignment_pairs_dict:
                 alignment_pairs_dict[alignment.query_idx] = []
 
             alignment_pairs_dict[alignment.query_idx].append(alignment.target_idx)
 
-        input_to_aligned_text_map: list[AltoAlignmentMap] = []
+        input_to_aligned_text_map: List[AltoAlignmentMap] = []
         for input_position, output_idx in [
             (x.input_position, x.output_idx) for x in self._input_output_map
         ]:
@@ -358,7 +359,7 @@ class AltoXMLTextLoader(TextLoader):
                     )
                     pass
 
-        input_to_aligned_text_map_dict: dict[str, list[int]] = {}
+        input_to_aligned_text_map_dict: Dict[str, List[int]] = {}
         # Yeah, that's a hacky bunch of shit in the middle to make the input key unique (it's almost the weekend and I don't want to think about the "right" way to do it)
         garbage = "@#$%^&"
         for alignment in input_to_aligned_text_map:
@@ -370,8 +371,8 @@ class AltoXMLTextLoader(TextLoader):
                 alignment.output_idx
             )
 
-        # aligned_transcription: list[str] = []
-        used_alinment_text_indices: list[int] = []
+        # aligned_transcription: List[str] = []
+        used_alinment_text_indices: List[int] = []
         for idx, entry in self.__serialized_xml.iterrows():
             line_text = ""
             for char_idx in range(len(entry.txt)):
