@@ -2,7 +2,6 @@ from typing import List
 from text_alignment_tool.shared_classes import TextChunk, LetterList
 from text_alignment_tool.text_loaders.text_loader import TextLoader
 import numpy as np
-import re
 
 
 class NewlineSeparatedTextLoader(TextLoader):
@@ -11,9 +10,7 @@ class NewlineSeparatedTextLoader(TextLoader):
         self.__input_text = input_text
 
     def _load(self) -> LetterList:
-        self._output = np.array(
-            [ord(" ") if x == "\n" else ord(x) for x in self.__input_text]
-        )
+        self._output = np.array([ord(x) for x in self.__input_text if x != "\n"])
 
         text_chunks: List[TextChunk] = []
         start_chunk_idx = 0
