@@ -18,3 +18,6 @@ from text_alignment_tool.text_transformers.consistent_bracketing_transformer imp
     BracketingPair,
     ConsistentBracketingTransformer,
 )
+from text_alignment_tool.text_transformers.remove_enclosed_transformer import (
+    RemoveEnclosedTransformer,
+)
